@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -65,7 +65,7 @@ void EmoticonUnicodeTab::loadEmoticons()
 void EmoticonUnicodeTab::createPlainTextEmoticonTab(const QString &str, const QVector<EmoticonUnicodeUtils::EmoticonStruct> &emoticons)
 {
     if (!emoticons.isEmpty()) {
-        auto *selector = new EmoticonListWidgetSelector(this);
+        auto selector = new EmoticonListWidgetSelector(this);
         connect(selector, &KPIMTextEdit::EmoticonListWidgetSelector::itemSelected, this, &EmoticonUnicodeTab::itemSelected);
         QStringList lst;
         lst.reserve(emoticons.count());
