@@ -47,6 +47,10 @@ private Q_SLOTS:
     void testBug421908();
     void testBug421908_2();
     void testBug421908_full();
+    void testBug436880();
+    void testBug442416();
+    void testBug442416Bis();
+    void testBugTextColor();
 };
 
 #endif // TEXTHTMLBUILDERTEST_H
