@@ -528,9 +528,13 @@ void MarkupDirector::processClosingElements(const QTextBlock::iterator &it)
                 break;
             case SpanBackground:
                 m_builder->endBackground();
+                // Clear background otherwise if we select 2 lines with same color it will not applied. bug #442416
+                d->m_openBackground = {};
                 break;
             case SpanForeground:
                 m_builder->endForeground();
+                // Clear forground text color otherwise if we select 2 lines with same text color it will not applied. bug #442416
+                d->m_openForeground = {};
                 break;
             case Anchor:
                 m_builder->endAnchor();
@@ -853,7 +857,7 @@ QList<int> MarkupDirector::sortOpeningOrder(QSet<int> openingOrder, QTextBlock::
         } else {
             // End of block. Need to close all open elements.
             // Order irrelevant in this case.
-            for (int tag : qAsConst(openingOrder)) {
+            for (int tag : std::as_const(openingOrder)) {
                 sortedOpenedElements.prepend(tag);
             }
             break;
