@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "plaintexteditorwidget.h"
-#include "plaintexteditor.h"
 #include "plaintexteditfindbar.h"
-#include "texttospeech/texttospeechwidget.h"
+#include "plaintexteditor.h"
 #include "slidecontainer.h"
+#include "texttospeech/texttospeechwidget.h"
 
-#include <QVBoxLayout>
 #include <QTextCursor>
+#include <QVBoxLayout>
 
 using namespace KPIMTextEdit;
 class Q_DECL_HIDDEN KPIMTextEdit::PlainTextEditorWidgetPrivate
@@ -78,7 +78,7 @@ QString PlainTextEditorWidget::toPlainText() const
 
 void PlainTextEditorWidget::init(PlainTextEditor *customEditor)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
     d->mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     lay->addWidget(d->mTextToSpeechWidget);
